==> org.eclipse.papyrus.designer.transformation.library.source_2.1.0.202201261931.jar: org/eclipse/papyrus/designer/transformation/library/xtend/AsyncCalls.java <==
package org.eclipse.papyrus.designer.transformation.library.xtend;

import org.eclipse.emf.common.util.EList;
import org.eclipse.papyrus.designer.transformation.library.xtend.CppUtils;
import org.eclipse.papyrus.designer.transformation.library.xtend.Marshalling;
import org.eclipse.uml2.uml.Operation;
import org.eclipse.uml2.uml.Type;
import org.eclipse.xtend2.lib.StringConcatenation;

@SuppressWarnings("all")
public class AsyncCalls {
  public CharSequence asyncCall(final Operation operation) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// TODO: need suitable constant dimensioning");
    _builder.newLine();
    _builder.append("pBuffer = &buffer[500];  // grows backwards");
    _builder.newLine();
    CharSequence _marshall = Marshalling.marshall(operation);
    _builder.append(_marshall);
    _builder.newLineIfNotEmpty();
    _builder.append("int operationID = ID_[operation.name/];");
    _builder.newLine();
    _builder.append("BEncAsnContent (&amp;pBuffer, &amp;operationID);");
    _builder.newLine();
    _builder.newLine();
    _builder.append("pthread_t pt;");
    _builder.newLine();
    _builder.append("pthread_create (&amp;pt, NULL, staticDispatch, (void *) this);");
    _builder.newLine();
    _builder.append("// TODO: add semaphore which assures that subsequent calls to ");
    String _name = operation.getName();
    _builder.append(_name);
    _builder.append(" are not executed before dispatch");
    _builder.newLineIfNotEmpty();
    _builder.append("// has removed the parameters from the pBuffer stack (pBuffer can be corrupted).");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence dispatch_(final org.eclipse.uml2.uml.Class clazz) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("int operationID;");
    _builder.newLine();
    _builder.append("BDecAsnContent (&pBuffer, operationID);");
    _builder.newLine();
    _builder.append("switch (operationID) {");
    _builder.newLine();
    {
      EList<Operation> _ownedOperations = clazz.getOwnedOperations();
      for(final Operation operation : _ownedOperations) {
        _builder.append("\t");
        _builder.append("case ID_");
        String _name = operation.getName();
        _builder.append(_name, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("{");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("\t");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("// delegate call to executor");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("rconn->");
        CharSequence _cppCall = CppUtils.cppCall(operation);
        _builder.append(_cppCall, "\t\t");
        _builder.append(";");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("break;");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence dispatchWithThreadPool(final org.eclipse.uml2.uml.Class clazz) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t");
    _builder.append("int operationID;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("BDecAsnContent (&pBuffer, operationID);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("switch (operationID) {");
    _builder.newLine();
    {
      EList<Operation> _ownedOperations = clazz.getOwnedOperations();
      for(final Operation operation : _ownedOperations) {
        _builder.append("\t\t");
        _builder.append("case ID_");
        String _name = operation.getName();
        _builder.append(_name, "\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("{");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("\t");
        CharSequence _unmarshall = Marshalling.unmarshall(operation);
        _builder.append(_unmarshall, "\t\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("// delegate call to executor");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("rconn->");
        CharSequence _cppCall = CppUtils.cppCall(operation);
        _builder.append(_cppCall, "\t\t\t");
        _builder.append(";");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        {
          Type _type = operation.getType();
          boolean _tripleNotEquals = (_type != null);
          if (_tripleNotEquals) {
            CharSequence _cppType = CppUtils.cppType(operation.getType());
            _builder.append(_cppType, "\t\t\t");
            _builder.append(" ret = ");
          }
        }
        _builder.append("rconn->");
        CharSequence _cppCall_1 = CppUtils.cppCall(operation);
        _builder.append(_cppCall_1, "\t\t\t");
        _builder.append(";");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        CharSequence _marshallOutInout = Marshalling.marshallOutInout(operation);
        _builder.append(_marshallOutInout, "\t\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("resultsReady = 1;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("break;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
}

==> org.eclipse.papyrus.designer.transformation.library.source_3.1.0.202407120007.jar: org/eclipse/papyrus/designer/transformation/library/xtend/AsyncCalls.java <==
/**
 * Copyright (c) 2022 CEA LIST.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 */
package org.eclipse.papyrus.designer.transformation.library.xtend;

import org.eclipse.emf.common.util.EList;
import org.eclipse.uml2.uml.Operation;
import org.eclipse.uml2.uml.Type;
import org.eclipse.xtend2.lib.StringConcatenation;

/**
 * text template to execute asynchrounous calls in the context of a component-based
 * implementation.
 * TODO: This class is referenced from the component library, but is not registered in the plugin.xml
 *   It's likely broken or deprecated
 */
@SuppressWarnings("all")
public class AsyncCalls {
  public CharSequence asyncCall(final Operation operation) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// TODO: need suitable constant dimensioning");
    _builder.newLine();
    _builder.append("pBuffer = &buffer[500];  // grows backwards");
    _builder.newLine();
    CharSequence _marshall = Marshalling.marshall(operation);
    _builder.append(_marshall);
    _builder.newLineIfNotEmpty();
    _builder.append("int operationID = ID_[operation.name/];");
    _builder.newLine();
    _builder.append("BEncAsnContent (&amp;pBuffer, &amp;operationID);");
    _builder.newLine();
    _builder.newLine();
    _builder.append("pthread_t pt;");
    _builder.newLine();
    _builder.append("pthread_create (&amp;pt, NULL, staticDispatch, (void *) this);");
    _builder.newLine();
    _builder.append("// TODO: add semaphore which assures that subsequent calls to ");
    String _name = operation.getName();
    _builder.append(_name);
    _builder.append(" are not executed before dispatch");
    _builder.newLineIfNotEmpty();
    _builder.append("// has removed the parameters from the pBuffer stack (pBuffer can be corrupted).");
    _builder.newLine();
    return _builder;
  }

  public CharSequence dispatch_(final org.eclipse.uml2.uml.Class clazz) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("int operationID;");
    _builder.newLine();
    _builder.append("BDecAsnContent (&pBuffer, operationID);");
    _builder.newLine();
    _builder.append("switch (operationID) {");
    _builder.newLine();
    {
      EList<Operation> _ownedOperations = clazz.getOwnedOperations();
      for(final Operation operation : _ownedOperations) {
        _builder.append("\t");
        _builder.append("case ID_");
        String _name = operation.getName();
        _builder.append(_name, "\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("{");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("\t");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("// delegate call to executor");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("rconn->");
        CharSequence _cppCall = CppUtils.cppCall(operation);
        _builder.append(_cppCall, "\t\t");
        _builder.append(";");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("\t");
        _builder.append("break;");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }

  public CharSequence dispatchWithThreadPool(final org.eclipse.uml2.uml.Class clazz) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t");
    _builder.append("int operationID;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("BDecAsnContent (&pBuffer, operationID);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("switch (operationID) {");
    _builder.newLine();
    {
      EList<Operation> _ownedOperations = clazz.getOwnedOperations();
      for(final Operation operation : _ownedOperations) {
        _builder.append("\t\t");
        _builder.append("case ID_");
        String _name = operation.getName();
        _builder.append(_name, "\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("{");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("\t");
        CharSequence _unmarshall = Marshalling.unmarshall(operation);
        _builder.append(_unmarshall, "\t\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("// delegate call to executor");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("rconn->");
        CharSequence _cppCall = CppUtils.cppCall(operation);
        _builder.append(_cppCall, "\t\t\t");
        _builder.append(";");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        {
          Type _type = operation.getType();
          boolean _tripleNotEquals = (_type != null);
          if (_tripleNotEquals) {
            CharSequence _cppType = CppUtils.cppType(operation.getType());
            _builder.append(_cppType, "\t\t\t");
            _builder.append(" ret = ");
          }
        }
        _builder.append("rconn->");
        CharSequence _cppCall_1 = CppUtils.cppCall(operation);
        _builder.append(_cppCall_1, "\t\t\t");
        _builder.append(";");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        CharSequence _marshallOutInout = Marshalling.marshallOutInout(operation);
        _builder.append(_marshallOutInout, "\t\t\t");
        _builder.newLineIfNotEmpty();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("resultsReady = 1;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("\t");
        _builder.append("break;");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
}
